##  Explicit Relations
Most relations in the SAP LeanIX meta model, and the ones you will create, are explicit or typed relations defined between fact sheet types on the SAP LeanIX meta model and work very well with SAP LeanIX's filtering and reporting capabilities. We highly recommend using this type of relation if available for your use case. In some cases, these relations include specific attributes to specify the relation (for example, “total annual costs” on the relation application – IT component or “usage” (CRUD) on the relation application – data object). These relations are typically between two different fact sheet types, but they can also be used between fact sheets of the same type (Think of a blocked/blocked by the relation between projects – a subtype of the fact sheet type business context).
